@@ -2125,6 +2125,13 @@ class SMTOtuApi
     	return self::CMD_reset_harddisk;
     }
     
+    // ssh strong/weak
+    const CMD_Get_Ssh_Personalization='OTU:SYST:COM:SSH?';    
+    static function getSsh_Personalization()
+    {
+    	return self::CMD_Get_Ssh_Personalization;
+    }
+    
 }
 
 
