@@ -1415,7 +1415,8 @@ class SMTLinkTest extends SMTServiceHelper
      */
     function getMinAttenuationAlarmThreshold( $moduleRunningNumber )
     {
-    	return $this->sendReceive( SMTOtuApi::getMinAttenuationAlarmThreshold( SMTOtuApi::RES_MOD.$moduleRunningNumber) );
+    	$min = $this->sendReceive( SMTOtuApi::getMinAttenuationAlarmThreshold( SMTOtuApi::RES_MOD.$moduleRunningNumber) );
+    	return floatval($min);
     }
     
     /**
